@@ -1,4 +1,4 @@
-path_catalogs='/Users/maayanesoumagnac/PostDoc/projects/catsHTM/data'
+path_catalogs=''# you cann add the path to the catalog here and use import params.py
 IndexFileTemplate='%s_htm.hdf5'
 CatFileTemplate='%s_htm_%06d.hdf5'
 htmTemplate='htm_%06d'
